/v1/projects/{project_id}/iou/vms/{vm_id}/initial_config — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »

# /v1/projects/{project_id}/iou/vms/{vm_id}/initial_config

Contents

- /v1/projects/{project_id}/iou/vms/{vm_id}/initial_config
  - GET /v1/projects/{project_id}/iou/vms/{vm_id}/initial_config
    - Response status codes
    - Output

## GET /v1/projects/{project_id}/iou/vms/{vm_id}/initial_config

Retrieve the initial config content

### Response status codes

- 200: Initial config retrieved
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
content | ✔ | ['string', 'null'] | Content of the initial configuration file

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »